| list2mniw | R Documentation |
Converts a list of return values of multiple calls to lmn_prior() or lmn_post() to a single list of MNIW parameters, which can then serve as vectorized arguments to the functions in mniw.
list2mniw(x)
x |
List of |
A list with the following elements:
LambdaThe mean matrices as an array of size p x p x n.
OmegaThe between-row precision matrices, as an array of size p x p x .
PsiThe between-column scale matrices, as an array of size q x q x n.
nuThe degrees-of-freedom parameters, as a vector of length n.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.